@@ -1,5 +1,4 @@
-quad2Dfit <- function( val, patternMap = visualFields::saplocmap$p24d2,
-                       bspos = visualFields::vfsettings$p24d2$bs ) {
+quad2Dfit <- function( val, patternMap, bspos ) {
 # fit a 2D quadratic function using values in val as "observations" for the x and y coordinates in patternMap
 
   val           <- as.data.frame( val )
@@ -10,7 +9,7 @@ quad2Dfit <- function( val, patternMap = visualFields::saplocmap$p24d2,
   val_sm        <- as.data.frame( val_sm )
 
 # remove blind spot
-  if( all( !is.na( bspos ) ) ) val_sm <- val_sm[-bspos,]
+  if( all( !is.na( bspos[1] ) ) ) val_sm <- val_sm[-bspos,]
 
   formula <- result ~ x + y + I( x^2 ) + I( y^2 )
 #  val_sm$result <- predict( lm( formula, data = val_sm ) )
