@@ -2,6 +2,8 @@ setnv <- function( nvtxt = "nvsapdefault" ) {
 
   nvinternal        <- eval( parse( text = nvtxt ) ) 
   nvinternal$nvname <- nvtxt
-  assign( "nv", nvinternal, envir = visualFields::vfenv )
+  texteval          <- "assign( \"nv\", nvinternal, envir = vfenv )"
+
+  eval( parse( text = texteval ) )
 
 }
